#
# spec file for package paps
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           paps
Version:        0.7.1
Release:        4.1
Summary:        A text to postscript converter through pango
License:        LGPL-2.0-only
Group:          System/Base
URL:            https://github.com/dov/%{name}
Source:         https://github.com/dov/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch1:         paps-cpi_scale_calculation.patch
Patch2:         paps-manpage_units.patch
Patch3:         paps-manpage_fixes.patch
Patch4:         paps-gutter-width.patch
Patch5:         paps-page_setup.patch
Patch6:         paps-layout.patch
Patch7:         paps-glib.patch
Patch8:         paps-header_features.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  intltool
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pangoft2)
Requires:       glibc-locale

%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}

%description
paps is a command line program for converting Unicode text encoded in UTF-8 to postscript and pdf by using pango.

%prep
%setup -qT -b0 -n %{name}-%{version}
%patch -P 1 -p0 -b .p1
%patch -P 2 -p0 -b .p2
%patch -P 3 -p0 -b .p3
%patch -P 4 -p0 -b .p4
%patch -P 5 -p0 -b .p5
%patch -P 6 -p0 -b .p6
%patch -P 7 -p0 -b .p7
%patch -P 8 -p0 -b .p8
mkdir -p config m4
for c in /usr/share/aclocal*/{codeset,gettext,glibc21,iconv,isc-posix,lcmessage}.m4
do
    test -e $c || continue
    cp -p $c m4/
done
for c in /usr/share/automake*/config.{guess,sub}
do
    test -e $c || continue
    cp -p $c .
done
unset c

%build
%add_optflags -D_XOPEN_SOURCE
echo "no" | glib-gettextize --force --copy
intltoolize --copy --force --automake
autoreconf --force --install -I config -I m4
automake --copy --force-missing --add-missing
%configure
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}

%files
%defattr(-,root,root)
%license COPYING.LIB
%{_bindir}/*
%{_mandir}/*/*

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Feb  7 2022 Dr. Werner Fink <werner@suse.de>
- For iconv glibc-locale should be installed
* Fri Dec  4 2020 Dr. Werner Fink <werner@suse.de>
- Add patch paps-header_features.patch which combines three
  patches to be able to change header font, date, and rule
  thickness
* Wed Oct  7 2020 Dr. Werner Fink <werner@suse.de>
- Update to paps 0.7.1
  * Added initial meson compilation support.
  * Minor accumulated bug fixes since 0.7.0
- Drop patch paps-prog_cc_c_o.patch as now solved upstream
* Mon May 13 2019 Dr. Werner Fink <werner@suse.de>
- Add patch paps-glib.patch to amke it build again ... seems to be
  a problem with the actuial linker as it ignores dependencies of
  the already specified libraries.
* Tue Dec  5 2017 werner@suse.de
- Add patch paps-layout.patch as a try to get page layout to
  something useful
* Tue Dec  5 2017 werner@suse.de
- Initial version paps from https://github.com/dov/paps master (was 37e6ca1)
- Add patches
    paps-prog_cc_c_o.patch to silent auto tools
    paps-cpi_scale_calculation.patch avoid possible miscalculated scale
    paps-manpage_units.patch make clear we are using points
    paps-manpage_fixes.patch for better understanding
    paps-gutter-width.patch enable to set gutter when printing multiple columns
    paps-page_setup.patch help modern PS viewers with page setup
